@@ -1,3 +1,6 @@
+from pathlib import Path
+
+
 import torch
 
 
@@ -11,6 +14,7 @@ class Client:
             self,
             client_num: int,
             client_id: str,
+            dataset_dir: Path,
             train_data: dict,
             eval_data: dict,
             model: type,
@@ -28,14 +32,14 @@ class Client:
         self.id = client_id
         self.group = group
 
-        self.train_data = self.model.generate_dataset(train_data)
-        self.eval_data = self.model.generate_dataset(eval_data)
+        self.train_data = self.model.generate_dataset(train_data, dataset_dir)
+        self.eval_data = self.model.generate_dataset(eval_data, dataset_dir)
 
         self._num_train_samples = len(self.train_data) if self.train_data is not None else 0
         self._num_eval_samples = len(self.eval_data) if self.eval_data is not None else 0
         self._num_samples = self.num_train_samples + self.num_eval_samples
 
-        self.flops = 0
+        self.metrics = {}
 
         self.init()
 
@@ -52,29 +56,35 @@ class Client:
 
     def train_model(self, compute_grads: bool = False):
         if compute_grads:
-            self.grads = []
+            grads = []
             for layer in self.model_params:
-                self.grads.append(layer.detach().clone())
+                grads.append(layer.detach().clone())
 
-        self.model = self.model.to(self.device)
-        self.flops = self.model.train_model(self.train_data, self.num_epochs, self.batch_size, self.device)
-        self.model = self.model.to("cpu")
+        self.model.to(self.device)
+        flops = self.model.train_model(self.train_data, self.num_epochs, self.batch_size, self.device)
+        self.model.to("cpu")
+
+        self.collect_metric(flops, constants.FLOPS_KEY)
 
         if compute_grads:
             for i, layer in enumerate(self.model_params):
-                self.grads[i] = layer - self.grads[i]
+                grads[i] = layer - grads[i]
+            
+            return grads
 
 
     def _train(self, num_epochs: int = 1, batch_size: int = 10) -> tuple:
         self.num_epochs = num_epochs
         self.batch_size = batch_size
 
+        self.metrics = {}
+
         update = self.train()
 
         training_result = {
             constants.CLIENT_ID_KEY: self.id,
             constants.NUM_SAMPLES_KEY: self.num_train_samples,
-            constants.FLOPS_KEY: self.flops
+            constants.METRICS_KEY: self.metrics
         }
 
         if type(update) == dict:
@@ -93,9 +103,9 @@ class Client:
         elif set_to_use == "test" or set_to_use == "val":
             data = self.eval_data
 
-        self.model = self.model.to(self.device)
+        self.model.to(self.device)
         eval_metrics = self.model.eval_model(data, batch_size, self.device)
-        self.model = self.model.to("cpu")
+        self.model.to("cpu")
 
         eval_metrics[stats.CLIENT_ID_KEY] = self.id
         return eval_metrics
@@ -111,16 +121,6 @@ class Client:
         self.model.set_params(params)
 
 
-    @property
-    def grads(self) -> list:
-        return self._grads
-
-    
-    @grads.setter
-    def grads(self, grads: list) -> None:
-        self._grads = grads
-
-
     @property
     def num_train_samples(self) -> int:
         return self._num_train_samples
@@ -164,3 +164,7 @@ class Client:
             res.append(torch.normal(mean=torch.ones(shape) * mean, std=torch.ones(shape) * std))
         
         return res.to(dtype)
+
+
+    def collect_metric(self, metric, metric_name):
+        self.metrics[metric_name] = metric
