@@ -1,3 +1,6 @@
+from pathlib import Path
+
+
 from torch import nn, Tensor
 from torch.utils.data import TensorDataset
 
@@ -37,12 +40,14 @@ class ClientModel(Model):
         self.loss_fn = nn.CrossEntropyLoss()
         self.optimizer = self.optimizer(self.parameters(), lr=self.lr)
     
-    def generate_dataset(self, data: dict) -> TensorDataset:
+    
+    def generate_dataset(self, data: dict, dataset_dir: Path) -> TensorDataset:
         return TensorDataset(
             Tensor(data["x"]).reshape(-1, 1, IMAGE_SIZE, IMAGE_SIZE),
             Tensor(data["y"]).long()
         )
 
+
     def forward(self, x):
         logits = self.cnn(x)
 
